@@ -119,6 +119,12 @@ class Client:
                 clientTask()
         _connect(True)
 
+    def ON_CONNECT(self, function):
+        events.registerEvent(events.Event("ON_CONNECT", function, scope=self.eventScope))
+
+    def ON_RECEIVE(self, function):
+        events.registerEvent(events.Event("ON_RECEIVE", function, scope=self.eventScope))
+
     def startAlive(self):
         def alive():
             time.sleep(self.aliveInterval)
