@@ -126,6 +126,15 @@ class Server:
             self.clientSocks.append(client)
             Thread(target=clientTask, args=[client, clientAddress]).start()
 
+    def ON_CLIENT_CONNECT(self, function):
+        events.registerEvent(events.Event("ON_CLIENT_CONNECT", function, scope=self.eventScope))
+
+    def ON_CLIENT_DISCONNECT(self, function):
+        events.registerEvent(events.Event("ON_CLIENT_DISCONNECT", function, scope=self.eventScope))
+
+    def ON_RECEIVE(self, function):
+        events.registerEvent(events.Event("ON_RECEIVE", function, scope=self.eventScope))
+
     def addPackageToPrintBlacklist(self, package):
         self.packagePrintBlacklist.append(package)
 
